==> haskell-knob-0.2.2-28-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-knob.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 knob
version:              0.2.2
visibility:           public
id:                   knob-0.2.2-HihKqJco8PCGnub0q4CgDJ
key:                  knob-0.2.2-HihKqJco8PCGnub0q4CgDJ
license:              MIT
maintainer:           Naïm Favier <n@monade.li>
author:               John Millikin <jmillikin@gmail.com>
stability:            experimental
homepage:             https://github.com/ncfavier/knob
synopsis:             Memory-backed handles
description:
    Create memory-backed '\''Handle'\''s, referencing virtual files. This is
    mostly useful for testing '\''Handle'\''-based APIs without having to
    interact with the filesystem.

    > import Data.ByteString (pack)
    > import Data.Knob
    > import System.IO
    >
    > main = do
    >     knob <- newKnob (pack [])
    >     h <- newFileHandle knob "test.txt" WriteMode
    >     hPutStrLn h "Hello world!"
    >     hClose h
    >     bytes <- Data.Knob.getContents knob
    >     putStrLn ("Wrote bytes: " ++ show bytes)

category:             System
abi:                  2ff3684707723953e68de27a66668993
exposed:              True
exposed-modules:      Data.Knob
import-dirs:          /usr/lib/ghc-9.2.8/site-local/knob-0.2.2
library-dirs:         /usr/lib/ghc-9.2.8/site-local/knob-0.2.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-knob
hs-libraries:         HSknob-0.2.2-HihKqJco8PCGnub0q4CgDJ
depends:
    base-4.16.4.0 bytestring-0.11.4.0 transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-knob/html/knob.haddock
haddock-html:         /usr/share/doc/haskell-knob/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-knob-0.2.2-56.1-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-knob.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 knob
version:              0.2.2
visibility:           public
id:                   knob-0.2.2-HhpH2zzkSI93rWV7pYCvrU
key:                  knob-0.2.2-HhpH2zzkSI93rWV7pYCvrU
license:              MIT
maintainer:           Naïm Favier <n@monade.li>
author:               John Millikin <jmillikin@gmail.com>
stability:            experimental
homepage:             https://github.com/ncfavier/knob
synopsis:             Memory-backed handles
description:
    Create memory-backed '\''Handle'\''s, referencing virtual files. This is
    mostly useful for testing '\''Handle'\''-based APIs without having to
    interact with the filesystem.

    > import Data.ByteString (pack)
    > import Data.Knob
    > import System.IO
    >
    > main = do
    >     knob <- newKnob (pack [])
    >     h <- newFileHandle knob "test.txt" WriteMode
    >     hPutStrLn h "Hello world!"
    >     hClose h
    >     bytes <- Data.Knob.getContents knob
    >     putStrLn ("Wrote bytes: " ++ show bytes)

category:             System
abi:                  d2d9f8b579bd559716da1fbf190768fd
exposed:              True
exposed-modules:      Data.Knob
import-dirs:          /usr/lib/ghc-9.4.8/site-local/knob-0.2.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/knob-0.2.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/knob-0.2.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-knob
hs-libraries:         HSknob-0.2.2-HhpH2zzkSI93rWV7pYCvrU
depends:
    base-4.17.2.1 bytestring-0.11.5.3 transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-knob/html/knob.haddock
haddock-html:         /usr/share/doc/haskell-knob/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
